(developer.scans)=
# Scans
BEC uses scans to orchestrate the data acquisition. While script-based scans can also be defined in the command-line interface, acquisitions that require more complex orchestration should be defined as scan plugins for the BEC scan server. This section describes the basic structure of a scan and how to create a scan plugin.

```{toctree}
---
maxdepth: 1
hidden: true
---
scan_structure/
scan_stubs/
tutorial_fly_scan_cont_line/
scan_metadata/
scan_gui_config/

```
